@@ -1,6 +1,7 @@
 package operator
 
 import (
+	"context"
 	"fmt"
 	"os"
 	"time"
@@ -8,6 +9,8 @@ import (
 	"github.com/golang/glog"
 
 	configclientset "github.com/openshift/client-go/config/clientset/versioned"
+	operatorv1 "github.com/openshift/client-go/operator/informers/externalversions/operator/v1"
+	operatorlisterv1 "github.com/openshift/client-go/operator/listers/operator/v1"
 	corev1 "k8s.io/api/core/v1"
 	apiextclientset "k8s.io/apiextensions-apiserver/pkg/client/clientset/clientset"
 	apiextinformersv1beta1 "k8s.io/apiextensions-apiserver/pkg/client/informers/externalversions/apiextensions/v1beta1"
@@ -23,6 +26,7 @@ import (
 	coreclientsetv1 "k8s.io/client-go/kubernetes/typed/core/v1"
 	appslisterv1 "k8s.io/client-go/listers/apps/v1"
 	corelisterv1 "k8s.io/client-go/listers/core/v1"
+
 	"k8s.io/client-go/tools/cache"
 	"k8s.io/client-go/tools/leaderelection/resourcelock"
 	"k8s.io/client-go/tools/record"
@@ -79,6 +83,7 @@ type Operator struct {
 	clusterCmLister  corelisterv1.ConfigMapLister
 	proxyLister      configlistersv1.ProxyLister
 	oseKubeAPILister corelisterv1.ConfigMapLister
+	etcdLister       operatorlisterv1.EtcdLister
 
 	crdListerSynced                  cache.InformerSynced
 	deployListerSynced               cache.InformerSynced
@@ -95,6 +100,7 @@ type Operator struct {
 	clusterRoleBindingInformerSynced cache.InformerSynced
 	proxyListerSynced                cache.InformerSynced
 	oseKubeAPIListerSynced           cache.InformerSynced
+	etcdSynced                       cache.InformerSynced
 
 	// queue only ever has one item, but it has nice error handling backoff/retry semantics
 	queue workqueue.RateLimitingInterface
@@ -126,6 +132,7 @@ func New(
 	apiExtClient apiextclientset.Interface,
 	configClient configclientset.Interface,
 	oseKubeAPIInformer coreinformersv1.ConfigMapInformer,
+	etcdInformer operatorv1.EtcdInformer,
 ) *Operator {
 	eventBroadcaster := record.NewBroadcaster()
 	eventBroadcaster.StartLogging(glog.Infof)
@@ -192,6 +199,17 @@ func New(
 	optr.infraListerSynced = infraInformer.Informer().HasSynced
 	optr.networkLister = networkInformer.Lister()
 	optr.networkListerSynced = networkInformer.Informer().HasSynced
+	if etcdInformer != nil {
+		optr.etcdLister = etcdInformer.Lister()
+		optr.etcdSynced = etcdInformer.Informer().HasSynced
+		etcdInformer.Informer().AddEventHandler(optr.eventHandler())
+	} else {
+		optr.etcdLister = nil
+		optr.etcdSynced = func() bool {
+			// if etcd is not part of CVO it will return true immediately
+			return true
+		}
+	}
 
 	optr.vStore.Set("operator", os.Getenv("RELEASE_VERSION"))
 
@@ -204,10 +222,10 @@ func (optr *Operator) Run(workers int, stopCh <-chan struct{}) {
 	defer optr.queue.ShutDown()
 
 	apiClient := optr.apiExtClient.ApiextensionsV1beta1()
-	_, err := apiClient.CustomResourceDefinitions().Get("machineconfigpools.machineconfiguration.openshift.io", metav1.GetOptions{})
+	_, err := apiClient.CustomResourceDefinitions().Get(context.TODO(), "controllerconfigs.machineconfiguration.openshift.io", metav1.GetOptions{})
 	if err != nil {
 		if apierrors.IsNotFound(err) {
-			glog.Infof("Couldn't find machineconfigpool CRD, in cluster bringup mode")
+			glog.Infof("Couldn't find controllerconfig CRD, in cluster bringup mode")
 			optr.inClusterBringup = true
 		} else {
 			glog.Errorf("While checking for cluster bringup: %v", err)
@@ -226,7 +244,10 @@ func (optr *Operator) Run(workers int, stopCh <-chan struct{}) {
 		optr.clusterRoleBindingInformerSynced,
 		optr.networkListerSynced,
 		optr.proxyListerSynced,
-		optr.oseKubeAPIListerSynced) {
+		optr.oseKubeAPIListerSynced,
+		optr.mcpListerSynced,
+		optr.mcListerSynced,
+		optr.etcdSynced) {
 		glog.Error("failed to sync caches")
 		return
 	}
@@ -234,9 +255,7 @@ func (optr *Operator) Run(workers int, stopCh <-chan struct{}) {
 	// these can only be synced after CRDs are installed
 	if !optr.inClusterBringup {
 		if !cache.WaitForCacheSync(stopCh,
-			optr.mcpListerSynced,
 			optr.ccListerSynced,
-			optr.mcListerSynced,
 		) {
 			glog.Error("failed to sync caches")
 			return
